@@ -6,7 +6,6 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
     "No file was uploaded" : "No se cargó el archivo",
     "Missing a temporary folder" : "Falta una carpeta temporal",
-    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
     "%s on %s" : "%s en %s",
     "Finished" : "Terminado",
@@ -26,6 +25,8 @@ OC.L10N.register(
     "Hide archived cards" : "Ocultar tarjetas archivadas",
     "Show archived cards" : "Mostrar tarjetas archivadas",
     "Details" : "Detalles",
+    "General" : "General",
+    "Search" : "Buscar",
     "Sharing" : "Compartiendo",
     "Tags" : "Etiquetas",
     "Activity" : "Actividad",
@@ -49,10 +50,6 @@ OC.L10N.register(
     "Remove due date" : "Eliminar fecha de expiración",
     "(group)" : "(grupo)",
     "seconds ago" : "hace segundos",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Action" : "Acción",
-    "Search" : "Buscar",
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
     "An error occurred" : "Se presentó un error",
@@ -64,11 +61,15 @@ OC.L10N.register(
     "Delete board" : "Borrar tableros",
     "Advanced options" : "Opciones avanzadas",
     "Export" : "Exportar",
-    "Today" : "Hoy",
-    "Tomorrow" : "Mañana",
     "Close" : "Cerrar",
     "Due date" : "Fecha de vencimiento",
     "Share" : "Compartir",
-    "Personal" : "Personal"
+    "Personal" : "Personal",
+    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Action" : "Acción",
+    "Today" : "Hoy",
+    "Tomorrow" : "Mañana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
