@@ -81,7 +81,6 @@ OC.L10N.register(
     "Load more" : "לטעון עוד",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} has assigned the card {deck-card} on {deck-board} to you.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
     "%s has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי %s בתגובה על „%s”.",
     "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
     "Deck board" : "לוח חסיפה",
@@ -141,6 +140,11 @@ OC.L10N.register(
     "Toggle compact mode" : "החלפת מצב חסכוני",
     "Open details" : "פתיחת פרטים",
     "Details" : "פרטים",
+    "General" : "כללי",
+    "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
+    "Appearance" : "מראה",
+    "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
+    "Search" : "חיפוש",
     "Loading board" : "הלוח נטען",
     "Board not found" : "הלוח לא נמצא",
     "Create a new list to add cards to this board" : "צור רשימה חדשה כדי להוסיף כרטיסים ללוח זה",
@@ -218,16 +222,9 @@ OC.L10N.register(
     "Unassign myself" : "לבטל את הקצאת עצמי",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "seconds ago" : "לפני מספר שניות",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
-    "Keyboard shortcut" : "קיצור מקלדת",
-    "Action" : "פעולה",
-    "Shift" : "הזזה",
-    "Search" : "חיפוש",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared with you" : "משותף אתך",
-    "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
-    "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
     "Cancel edit" : "בטל עריכה",
     "Board {0} deleted" : "הלוח {0} נמחק",
     "All cards" : "כל הכרטיסים",
@@ -265,12 +262,16 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
     "Share" : "שיתוף",
     "Personal" : "אישי",
+    "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
     "To do" : "לעשות",
     "Doing" : "בביצוע",
     "Example Task 3" : "משימה לדוגמה 3",
     "Example Task 2" : "משימה לדוגמה 2",
     "Example Task 1" : "משימה לדוגמה 1",
-    "Move card to another board" : "העברת כרטיס ללוח אחר",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Keyboard shortcut" : "קיצור מקלדת",
+    "Action" : "פעולה",
+    "Shift" : "הזזה",
     "Today" : "היום",
     "Tomorrow" : "מחר",
     "No due" : "אין תאריך יעד"
