@@ -79,7 +79,6 @@ OC.L10N.register(
     "Load more" : "Učitaj više",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Karticu „%s” na „%s” dodijelio vam je %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam je dodijelio karticu {deck-card} na {deck-board}.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
     "The card {deck-card} on {deck-board} has reached its due date." : "Kartica {deck-card} na {deck-board} dosegla je datum dospijeća.",
     "%s has mentioned you in a comment on \"%s\"." : "%s vas spominje u komentaru na „%s”.",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} vas je spomenuo u komentaru na {deck-card}.",
@@ -144,6 +143,11 @@ OC.L10N.register(
     "Toggle compact mode" : "Prebaci u kompaktni način rada",
     "Open details" : "Otvori pojedinosti",
     "Details" : "Pojedinosti",
+    "General" : "Općenito",
+    "Use bigger card view" : "Prikaži veće kartice",
+    "Appearance" : "Izgled",
+    "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
+    "Search" : "Traži",
     "Loading board" : "Učitavanje ploče",
     "Board not found" : "Ploča nije pronađena",
     "Create a new list to add cards to this board" : "Stvorite novi popis kako biste dodali kartice na ovu ploču",
@@ -225,16 +229,9 @@ OC.L10N.register(
     "Unassign myself" : "Ukloni sebe",
     "Delete card" : "Izbriši karticu",
     "seconds ago" : "prije nekoliko sekundi",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
-    "Keyboard shortcut" : "Tipkovni prečac",
-    "Action" : "Radnja",
-    "Shift" : "Pomakni",
-    "Search" : "Traži",
     "All boards" : "Sve ploče",
     "Archived boards" : "Arhivirane ploče",
     "Shared with you" : "Podijeljeno s vama",
-    "Use bigger card view" : "Prikaži veće kartice",
-    "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
     "Cancel edit" : "Otkaži uređivanje",
     "Board {0} deleted" : "Ploča {0} je izbrisana",
     "All cards" : "Sve kartice",
@@ -283,12 +280,16 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
     "Share" : "Dijeli",
     "Personal" : "Osobno",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
     "To do" : "Zadatak",
     "Doing" : "U postupku",
     "Example Task 3" : "Primjer zadatka 3.",
     "Example Task 2" : "Primjer zadatka 2.",
     "Example Task 1" : "Primjer zadatka 1.",
-    "Move card to another board" : "Premjesti karticu na drugu ploču",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Keyboard shortcut" : "Tipkovni prečac",
+    "Action" : "Radnja",
+    "Shift" : "Pomakni",
     "Today" : "Danas",
     "Tomorrow" : "Sutra",
     "No due" : "Nema nezavršenih"
