@@ -131,6 +131,9 @@ OC.L10N.register(
     "Show archived cards" : "Tampilan arsip kartu",
     "Toggle compact mode" : "Beralih mode ringkas",
     "Details" : "Detail",
+    "General" : "Umum",
+    "Appearance" : "Tampilan",
+    "Search" : "Cari",
     "Loading board" : "Memuat papan",
     "Board not found" : "Papan tidak ditemukan",
     "Sharing" : "Berbagi",
@@ -191,9 +194,6 @@ OC.L10N.register(
     "Assign to me" : "Tugaskan saya",
     "Delete card" : "Hapus kartu",
     "seconds ago" : "beberapa detik yang lalu",
-    "Keyboard shortcuts" : "Pintasan keyboard",
-    "Keyboard shortcut" : "Pintasan keyboard",
-    "Search" : "Cari",
     "All boards" : "Semua papan",
     "Archived boards" : "Papan terarsip",
     "Shared with you" : "Shared with you",
@@ -229,6 +229,8 @@ OC.L10N.register(
     "Example Task 3" : "Contoh tugas 3",
     "Example Task 2" : "Contoh tugas 2",
     "Example Task 1" : "Contoh tugas 1",
+    "Keyboard shortcuts" : "Pintasan keyboard",
+    "Keyboard shortcut" : "Pintasan keyboard",
     "Today" : "Hari ini",
     "Tomorrow" : "Besok"
 },
