@@ -2,8 +2,10 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "დასტა",
-    "Personal" : "პირადი",
-    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
+    "No file was uploaded" : "ფაილი არ აიტვირთა",
+    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
     "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
     "%s on %s" : "%s %s-ზე",
     "Finished" : "დასრულდა",
@@ -11,10 +13,7 @@ OC.L10N.register(
     "Action needed" : "საჭიროა ქმედება",
     "Later" : "მოგვიანებით",
     "Done" : "დასრულებულია",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
-    "No file was uploaded" : "ფაილი არ აიტვირთა",
-    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
+    "File" : "ფაილი",
     "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
     "Cancel" : "უარყოფა",
     "File already exists" : "ფაილი უკვე არსებობს",
@@ -25,6 +24,8 @@ OC.L10N.register(
     "Hide archived cards" : "არქივირებული ბარათების დამალვა",
     "Show archived cards" : "არქივირებული ბარათების ჩვენება",
     "Details" : "დეტალები",
+    "General" : "ზოგადი",
+    "Search" : "ძიება",
     "Sharing" : "გაზიარება",
     "Tags" : "ტეგები",
     "Activity" : "აქტივობა",
@@ -36,22 +37,18 @@ OC.L10N.register(
     "Edit" : "შეცვლა",
     "Members" : "წევრები",
     "Download" : "ჩამოტვირთვა",
-    "Comments" : "კომენტარები",
     "Modified" : "შეიცვალა",
     "Created" : "შექმნილია",
+    "Comments" : "კომენტარები",
     "Save" : "შენახვა",
+    "Created:" : "შექმნილია:",
     "Reply" : "პასუხი",
     "Update" : "განახლება",
-    "Created:" : "შექმნილია:",
     "Description" : "აღწერა",
     "Formatting help" : "დახმარება ფორმატირებაზე",
     "Remove due date" : "მოაშორეთ დანიშნულების დრო",
     "(group)" : "(ჯგუფი)",
     "seconds ago" : "წამის წინ",
-    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
-    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
-    "Action" : "ქმედება",
-    "Search" : "ძიება",
     "Archived boards" : "არქივირებული დაფები",
     "Shared with you" : "გაზიარებული თქვენთან",
     "Board details" : "დაფის დეტალები",
@@ -60,9 +57,17 @@ OC.L10N.register(
     "Archive board" : "დაფის არქივირება",
     "No notifications" : "შეტყობინებები არაა",
     "Delete board" : "დაფის გაუქმება",
-    "Today" : "დღეს",
-    "Tomorrow" : "ხვალ",
+    "Advanced options" : "დამატებითი ოპციონები",
+    "Export" : "ექსპორტი",
     "Close" : "დახურვა",
-    "Share" : "გაზიარება"
+    "Due date" : "განპირობებულია თარიღისთვის",
+    "Share" : "გაზიარება",
+    "Personal" : "პირადი",
+    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
+    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
+    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
+    "Action" : "ქმედება",
+    "Today" : "დღეს",
+    "Tomorrow" : "ხვალ"
 },
 "nplurals=2; plural=(n!=1);");
