@@ -6,16 +6,22 @@ OC.L10N.register(
     "No file was uploaded" : "Ulac afaylu i d-yettwasulin",
     "Missing a temporary folder" : "Ixuṣ ukaram akudan",
     "Finished" : "Immed",
+    "copy" : "nɣel",
     "Done" : "Immed",
     "Attachments" : "Ticeqqufin",
     "File" : "Afaylu",
     "Cancel" : "Sefsex",
     "Open" : "Ldi",
     "Completed" : "Yemmed",
+    "Open details" : "Ldi talqayt",
     "Details" : "Talqayt",
+    "General" : "Amatu",
+    "Appearance" : "Udem",
+    "Search" : "Nadi",
     "Sharing" : "Beṭṭu",
     "Tags" : "Tibzimin",
     "Activity" : "Armud",
+    "Transfer" : "Seḍfeṛ",
     "Owner" : "Bab",
     "Delete" : "Kkes",
     "Edit" : "Ẓreg",
@@ -26,12 +32,15 @@ OC.L10N.register(
     "Save" : "Sekles",
     "Cancel reply" : "Semmet tiririt.",
     "Reply" : "Err",
-    "Search" : "Nadi",
+    "Description" : "Aglam",
+    "Open link" : "Nɣel aseɣwen",
     "Cancel edit" : "Sefsex aseẓreg",
     "No notifications" : "Ulac tisezmal",
-    "Today" : "Ass-a",
     "Close" : "Mdel",
     "Share" : "Bḍu",
-    "Personal" : "Udmawan"
+    "Personal" : "Udmawan",
+    "Keyboard shortcuts" : "Inegzumen n unasiw",
+    "Ctrl" : "Ctrl",
+    "Today" : "Ass-a"
 },
 "nplurals=2; plural=(n != 1);");
