@@ -6,6 +6,8 @@ OC.L10N.register(
     "File" : "ឯកសារ",
     "Cancel" : "បោះបង់",
     "Details" : "ព័ត៌មាន​លម្អិត",
+    "General" : "ទូទៅ",
+    "Search" : "ស្វែងរក",
     "Sharing" : "ការ​ចែក​រំលែក",
     "Tags" : "ស្លាក",
     "Activity" : "សកម្មភាព",
@@ -22,12 +24,11 @@ OC.L10N.register(
     "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
     "Description" : "ការ​អធិប្បាយ",
     "seconds ago" : "វិនាទី​មុន",
-    "Search" : "ស្វែងរក",
     "Shared with you" : "Shared with you",
     "Export" : "នាំចេញ",
-    "Today" : "ថ្ងៃ​នេះ",
     "Close" : "បិទ",
     "Share" : "ចែក​រំលែក",
-    "Personal" : "ផ្ទាល់​ខ្លួន"
+    "Personal" : "ផ្ទាល់​ខ្លួន",
+    "Today" : "ថ្ងៃ​នេះ"
 },
 "nplurals=1; plural=0;");
