@@ -66,11 +66,19 @@ OC.L10N.register(
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Spremembe v programu <strong>Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
+    "The file was uploaded" : "Datoteka je uspešno poslana.",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo največje dovoljene velikosti v datoteki php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
+    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
+    "No file was uploaded" : "Datoteka ni bila poslana",
+    "Missing a temporary folder" : "Manjka začasna mapa",
+    "Could not write file to disk" : "Ni mogoče zapisati datoteke na disk",
+    "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
+    "No file uploaded or file size exceeds maximum of %s" : "Ali ni poslane datoteke ali pa velikost datoteke presega omejitev %s",
     "Upcoming cards" : "Prihajajoče naloge",
     "Load more" : "Naloži več",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Nalogo »%s« na »%s« vam dodeli %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam dodeli nalogo »{deck-card}« na »{deck-board}«.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "Naloga »%s« na »%s« je dosegla datum preteka.",
     "The card {deck-card} on {deck-board} has reached its due date." : "Naloga »{deck-card} « na »{deck-board}« je dosegla datum preteka.",
     "%s has mentioned you in a comment on \"%s\"." : "%s vas omeni v opombi na »%s«.",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} vas omeni v opombi na »{deck-card}«.",
@@ -87,21 +95,14 @@ OC.L10N.register(
     "copy" : "kopija",
     "To Do" : "Naloge",
     "Done" : "Končane naloge",
-    "The file was uploaded" : "Datoteka je uspešno poslana.",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo največje dovoljene velikosti v datoteki php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
-    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
-    "No file was uploaded" : "Datoteka ni bila poslana",
-    "Missing a temporary folder" : "Manjka začasna mapa",
-    "Could not write file to disk" : "Ni mogoče zapisati datoteke na disk",
-    "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
-    "No file uploaded or file size exceeds maximum of %s" : "Ali ni poslane datoteke ali pa velikost datoteke presega omejitev %s",
+    "Attachments" : "Priloge",
+    "File" : "Datoteka",
     "Card not found" : "Naloge ni mogoče najti",
     "Path is already shared with this card" : "Pot je že povezana s to nalogo",
     "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
     "Personal planning and team project organization" : "Osebno načrtovanje nalog in organizacija skupinskih projektov",
-    "Card details" : "Podrobnosti naloge",
     "Add board" : "Dodaj zbirko",
+    "Card details" : "Podrobnosti naloge",
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
     "Search by board title" : "Išči po imenu zbirke",
     "Select board" : "Izbor zbirke",
@@ -109,17 +110,17 @@ OC.L10N.register(
     "No lists available" : "Ni razpoložljivih seznamov",
     "Select a list" : "Izbor seznama",
     "Move card" : "Premakni nalogo",
-    "Select a card" : "Izbor naloge",
-    "Cancel" : "Prekliči",
     "Select the card to link to a project" : "Izbor naloge za povezavo do projekta",
     "Link to card" : "Poveži nalogo",
+    "Select a card" : "Izbor naloge",
+    "Cancel" : "Prekliči",
+    "This board is read only" : "Zbirka je označena le za branje",
+    "Drop your files to upload" : "Spustite datoteke za pošiljanje v oblak",
     "File already exists" : "Datoteka s tem imenom že obstaja.",
     "A file with the name {filename} already exists." : "Datoteka z imenom {filename} že obstaja.",
     "Do you want to overwrite it?" : "Ali želite predmet prepisati?",
     "Overwrite file" : "Prepiši datoteko",
     "Keep existing file" : "Ohrani obstoječe datoteke",
-    "This board is read only" : "Zbirka je označena le za branje",
-    "Drop your files to upload" : "Spustite datoteke za pošiljanje v oblak",
     "Add card" : "Dodaj nalogo",
     "Archived cards" : "Arhivirane naloge",
     "Add list" : "Dodaj seznam",
@@ -147,6 +148,20 @@ OC.L10N.register(
     "Toggle compact mode" : "Preklopi način prikaza",
     "Open details" : "Odpri podrobnosti",
     "Details" : "Podrobnosti",
+    "General" : "Splošno",
+    "Use bigger card view" : "Uporabi povečan pogled nalog",
+    "Appearance" : "Videz",
+    "Show boards in calendar/tasks" : "Pokaži zbirke v koledarjem in med opravili",
+    "Scroll sideways" : "Zdrsni bočno",
+    "Navigate between cards" : "Krmarjenje med nalogami",
+    "Close card details" : "Zapri podrobnosti kartice",
+    "Search" : "Poišči",
+    "Show card filters" : "Pokaži filtre kartice",
+    "Clear card filters" : "Počisti filtre kartice",
+    "Show those shortcuts" : "Pokaži tipkovne bližnjice",
+    "Card actions" : "Dejanja naloge",
+    "Open card details" : "Odpri podrobnosti naloge",
+    "Edit the card title" : "Uredi naslov naloge",
     "Loading board" : "Poteka nalaganje zbirke",
     "Board not found" : "Zbirke ni mogoče najti",
     "Create a new list to add cards to this board" : "Ustvari nov seznam in doda kartice v zbirko",
@@ -157,6 +172,8 @@ OC.L10N.register(
     "Deleted lists" : "Izbrisani seznami",
     "Undo" : "Razveljavi",
     "Deleted cards" : "Izbrisane naloge",
+    "Failed to create share with {displayName}" : "Souporaba z uporabnikom {displayName} je spodletela",
+    "Transfer" : "Prenos",
     "No participants found" : "Ni zaznanih udeleženev",
     "Board owner" : "Lastnik zbirke",
     "(Group)" : "(Skupina)",
@@ -165,20 +182,20 @@ OC.L10N.register(
     "Can manage" : "Lahko upravlja",
     "Owner" : "Lastnik",
     "Delete" : "Izbriši",
-    "Failed to create share with {displayName}" : "Souporaba z uporabnikom {displayName} je spodletela",
-    "Transfer" : "Prenos",
+    "List deleted" : "Seznam je izbrisan",
     "Archive all cards" : "Arhiviraj vse kartice",
     "Delete list" : "Izbriši seznam",
     "Archive all cards in this list" : "Arhiviraj vse kartice tega seznama",
     "Add a new card" : "Dodaj novo nalogo",
     "Card name" : "Ime kartice",
-    "List deleted" : "Seznam je izbrisan",
+    "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
     "Edit" : "Uredi",
     "Add a new tag" : "Dodaj novo oznako",
-    "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
     "Board name" : "Ime zbirke",
     "Members" : "Člani",
     "Assign a user to this card…" : "Dodeli uporabnika k nalogi ...",
+    "File to share" : "Datoteka za souporabo",
+    "Invalid path selected" : "Izbrana je neveljavna pot",
     "Upload new files" : "Pošlji nove datoteke",
     "Share from Files" : "Poveži iz oblaka",
     "Add this attachment" : "Dodaj prilogo",
@@ -187,25 +204,23 @@ OC.L10N.register(
     "Remove attachment" : "Odstrani prilogo",
     "Delete Attachment" : "Izbriši prilogo",
     "Restore Attachment" : "Obnovi prilogo",
-    "File to share" : "Datoteka za souporabo",
-    "Invalid path selected" : "Izbrana je neveljavna pot",
-    "Open in sidebar view" : "Odpri v bočnem pogledu",
-    "Open in bigger view" : "Odpri v povečanem pogledu",
-    "Attachments" : "Priloge",
-    "Comments" : "Opombe",
     "Modified" : "Spremenjeno",
     "Created" : "Ustvarjeno",
     "The title cannot be empty." : "Polje naslova ne sme biti prazno.",
-    "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
+    "Open in sidebar view" : "Odpri v bočnem pogledu",
+    "Open in bigger view" : "Odpri v povečanem pogledu",
+    "Comments" : "Opombe",
     "Failed to load comments" : "Nalaganje opomb je spodletelo.",
-    "Save" : "Shrani",
+    "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
     "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
     "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
+    "Save" : "Shrani",
+    "Created:" : "Ustvarjeno:",
     "In reply to" : "V odgovor",
     "Cancel reply" : "Prekliči odgovor",
     "Reply" : "Odgovori",
     "Update" : "Posodobi",
-    "Created:" : "Ustvarjeno:",
+    "Write a description …" : "Vpišite opis ...",
     "Description" : "Opis",
     "(Unsaved)" : "(neshranjeno)",
     "(Saving…)" : "(shranjevanje ...)",
@@ -213,8 +228,16 @@ OC.L10N.register(
     "Edit description" : "Uredi opis",
     "View description" : "Pokaži opis",
     "Add Attachment" : "Dodaj prilogo",
-    "Write a description …" : "Vpišite opis ...",
     "Choose attachment" : "Izbor priloge",
+    "Select Date" : "Izbor datuma",
+    "Later today – {timeLocale}" : "Danes – {timeLocale}",
+    "Set due date for later today" : "Nastavi datum preteka na danes kasneje",
+    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
+    "Set due date for tomorrow" : "Nastavi datum preteka na jutri",
+    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
+    "Set due date for this weekend" : "Nastavi datum preteka na ta teden",
+    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
+    "Set due date for next week" : "Nastavi datum preteka na naslednji teden",
     "Set a due date" : "Nastavi datum preteka",
     "Add due date" : "Dodaj datum preteka",
     "Choose a date" : "Izbor datuma",
@@ -224,52 +247,30 @@ OC.L10N.register(
     "Not done" : "Ni končano",
     "Unarchive card" : "Povrni nalogo",
     "Archive card" : "Arhiviraj nalogo",
-    "Select Date" : "Izbor datuma",
-    "Set due date for later today" : "Nastavi datum preteka na danes kasneje",
-    "Set due date for tomorrow" : "Nastavi datum preteka na jutri",
-    "Set due date for this weekend" : "Nastavi datum preteka na ta teden",
-    "Set due date for next week" : "Nastavi datum preteka na naslednji teden",
     "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
     "Select or create a tag…" : "Izberi ali ustvari oznako ...",
     "Create a new tag:" : "Ustvari novo oznako:",
     "(group)" : "(skupina)",
-    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
-    "Todo items" : "Naloge",
     "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
+    "Todo items" : "Naloge",
     "Edit card title" : "Uredi naslov naloge",
+    "Card deleted" : "Naloga je izbrisana",
     "Edit title" : "Uredi naslov",
     "Assign to me" : "Nalogo dodeli meni",
     "Unassign myself" : "Odstrani me z naloge",
     "Mark as not done" : "Označi kot Ni končano",
     "Delete card" : "Izbriši nalogo",
-    "Card deleted" : "Naloga je izbrisana",
     "seconds ago" : "pred nekaj sekundami",
-    "Keyboard shortcuts" : "Tipkovne bližnjice",
-    "Boost your productivity using Deck with keyboard shortcuts." : "Povečaj hitrost dela z uporabo tipkovnih bližnjic",
-    "Keyboard shortcut" : "Tipkovna bližnjica",
-    "Action" : "Dejanje",
-    "Shift" : "Premakni",
-    "Scroll" : "Zdrsni",
-    "Scroll sideways" : "Zdrsni bočno",
-    "Navigate between cards" : "Krmarjenje med nalogami",
-    "Esc" : "Esc",
-    "Close card details" : "Zapri podrobnosti kartice",
-    "Ctrl" : "CTRL",
-    "Search" : "Poišči",
-    "Show card filters" : "Pokaži filtre kartice",
-    "Clear card filters" : "Počisti filtre kartice",
-    "Show help dialog" : "Pokaži okno pomoči",
-    "Card actions" : "Dejanja naloge",
-    "Enter" : "Vnos",
-    "Space" : "Presledek",
-    "Open card details" : "Odpri podrobnosti naloge",
-    "Edit the card title" : "Uredi naslov naloge",
     "All boards" : "Vse zbirke",
     "Archived boards" : "Arhivirane zbirke",
     "Shared with you" : "V souporabi z vami",
-    "Use bigger card view" : "Uporabi povečan pogled nalog",
-    "Show boards in calendar/tasks" : "Pokaži zbirke v koledarjem in med opravili",
     "Cancel edit" : "Prekliči urejanje",
+    "Board {0} deleted" : "Zbirka {0} je izbrisana",
+    "All cards" : "Vse naloge",
+    "Only assigned cards" : "Le dodeljene naloge",
+    "No reminder" : "Ni vpisanih opomnikov",
+    "An error occurred" : "Prišlo je do napake.",
+    "Delete the board?" : "Ali želite izbrisati zbirko?",
     "Board details" : "Podrobnosti zbirke",
     "Edit board" : "Uredi zbirko",
     "Clone board" : "Kloniraj zbirko",
@@ -278,29 +279,23 @@ OC.L10N.register(
     "Turn on due date reminders" : "Omogoči opomnike o datumu zapadlosti ",
     "Turn off due date reminders" : "Onemogoči opomnike o datumu zapadlosti",
     "Due date reminders" : "Opomniki o datumu zapadlosti",
-    "All cards" : "Vse naloge",
     "Assigned cards" : "Dodeljene naloge",
     "No notifications" : "Ni obvestil",
     "Delete board" : "Izbriši zbirko",
-    "Board {0} deleted" : "Zbirka {0} je izbrisana",
-    "Only assigned cards" : "Le dodeljene naloge",
-    "No reminder" : "Ni vpisanih opomnikov",
-    "An error occurred" : "Prišlo je do napake.",
-    "Delete the board?" : "Ali želite izbrisati zbirko?",
     "Clone cards" : "Kloniraj nalogo",
     "Advanced options" : "Napredne možnosti",
     "Clone" : "Kloniraj",
+    "Export as CSV" : "Izvozi v zapis CSV",
+    "Export" : "Izvozi",
     "Loading filtered view" : "Poteka nalaganje filtriranega pogleda",
-    "Today" : "Danes",
-    "Tomorrow" : "Jutri",
-    "No due" : "Ni datuma preteka",
     "Search for {searchQuery} in all boards" : "Poišči {searchQuery} med vsemi zbirkami nalog.",
     "No results found" : "Ni najdenih zadetkov",
+    "Due on {date}" : "Poteče {date}",
     "{stack} in {board}" : "{stack} v {board}",
     "Click to expand comment" : "Kliknite za razširitev opombe",
+    "Create card" : "Ustvari nalogo",
     "Create a new card" : "Ustvari novo nalogo",
     "Card title" : "Naslov naloge",
-    "Create card" : "Ustvari nalogo",
     "Creating the new card …" : "Poteka ustvarjanje nove naloge ...",
     "Card \"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
     "Open card" : "Odpri nalogo",
@@ -308,10 +303,6 @@ OC.L10N.register(
     "No upcoming cards" : "Ni prihajajočih nalog",
     "upcoming cards" : "prihajajoče naloge",
     "New card" : "Nova naloga",
-    "Due on {date}" : "Poteče {date}",
-    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
-    "Later today – {timeLocale}" : "Danes – {timeLocale}",
     "Link to a board" : "Povezava do zbirke",
     "Link to a card" : "Povezava do naloge",
     "Create a card" : "Ustvari nalogo",
@@ -319,16 +310,31 @@ OC.L10N.register(
     "Something went wrong" : "Prišlo je do napake ...",
     "Failed to upload {name}" : "Pošiljanje {name} je spodletelo",
     "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena.",
+    "Due date" : "Datum preteka",
     "Error creating the share" : "Napaka ustvarjanja mesta souporabe",
     "Share with a Deck card" : "Poveži z nalogo Deck",
     "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
     "Share" : "Souporaba",
     "Personal" : "Osebno",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Naloga »%s« na »%s« je dosegla datum preteka.",
     "To do" : "Prihajajoče naloge",
     "Doing" : "Naloge v teku",
     "Example Task 3" : "Primer naloge 3",
     "Example Task 2" : "Primer naloge 2",
     "Example Task 1" : "Primer naloge 1",
-    "Move card to another board" : "Premakni nalogo v drugo zbirko"
+    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "Boost your productivity using Deck with keyboard shortcuts." : "Povečaj hitrost dela z uporabo tipkovnih bližnjic",
+    "Keyboard shortcut" : "Tipkovna bližnjica",
+    "Action" : "Dejanje",
+    "Shift" : "Premakni",
+    "Scroll" : "Zdrsni",
+    "Esc" : "Esc",
+    "Ctrl" : "CTRL",
+    "Show help dialog" : "Pokaži okno pomoči",
+    "Enter" : "Vnos",
+    "Space" : "Presledek",
+    "Today" : "Danes",
+    "Tomorrow" : "Jutri",
+    "No due" : "Ni datuma preteka"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
