@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -52,10 +53,10 @@ class FilesAppService implements IAttachmentService, ICustomAttachmentService {
 		IPreview $preview,
 		IMimeTypeDetector $mimeTypeDetector,
 		PermissionService $permissionService,
-		CardMapper  $cardMapper,
+		CardMapper $cardMapper,
 		LoggerInterface $logger,
 		IDBConnection $connection,
-		?string $userId
+		?string $userId,
 	) {
 		$this->request = $request;
 		$this->l10n = $l10n;
@@ -161,7 +162,15 @@ class FilesAppService implements IAttachmentService, ICustomAttachmentService {
 	}
 
 	public function create(Attachment $attachment) {
-		$file = $this->getUploadedFile();
+		if ($attachment->getData() === 'DEFAULT_SAMPLE_FILE' && !$this->request->getUploadedFile('file')) {
+			$file = [
+				'name' => 'Nextcloud sample image - add your image here!.jpg',
+				'tmp_name' => __DIR__ . '/../../img/sample-image.jpg',
+			];
+		} else {
+			$file = $this->getUploadedFile();
+		}
+
 		$fileName = $file['name'];
 
 		// get shares for current card
